@@ -2,24 +2,24 @@
  * gbpserial.c: communicate with a GemPC410 smart card reader
  * using GemCore protocol
  * Copyright (C) 2001,2002 Ludovic Rousseau
- * 
- * This program is free software; you can redistribute it and/or modify it 
+ *
+ * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
  * Free Software Foundation; either version 2 of the License, or (at your
  * option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
- * 
- * You should have received a copy of the GNU General Public License along 
- * with this program; if not, write to the Free Software Foundation, Inc., 
- * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA 
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
 /*
- * $Id: gbpserial.c,v 1.40 2010-06-16 13:08:22 rousseau Exp $
+ * $Id: gbpserial.c,v 1.43 2012/04/08 19:09:42 rousseau Exp $
  */
 
 #include <stdio.h>
@@ -135,7 +135,7 @@ int ExplainGBP(const unsigned char buffer[], const int rv);
 		DEBUG_INFO2("tcflush() function error: %s", strerror(errno));
 
 /*****************************************************************************
- * 
+ *
  *				WriteGBP: Send bytes to the card reader
  *
  * remark: buffer already contains the byte length in [0]
@@ -188,7 +188,7 @@ RESPONSECODE WriteGBP(DWORD lun, DWORD length, PUCHAR buffer)
 
 
 /*****************************************************************************
- * 
+ *
  *				ReadGBP: Receive bytes from the card reader
  *
  * remark: buffer contains the byte length in [0]
@@ -315,7 +315,7 @@ RESPONSECODE ReadGBP(DWORD lun, PDWORD length, PUCHAR buffer)
 
 
 /*****************************************************************************
- * 
+ *
  *				OpenGBP: open the port
  *
  *****************************************************************************/
@@ -325,7 +325,7 @@ RESPONSECODE OpenGBP(DWORD lun, LPSTR dev_name)
 	int ospeed, i;
 	int reader = LunToReaderIndex(lun);
 
-	DEBUG_COMM3("Lun: %X, device: %s", lun, dev_name);
+	DEBUG_COMM3("Lun: %lX, device: %s", lun, dev_name);
 
 	/* check if the same channel is not already used */
 	for (i=0; i<PCSCLITE_MAX_READERS; i++)
@@ -571,7 +571,7 @@ RESPONSECODE OpenGBP(DWORD lun, LPSTR dev_name)
 
 
 /*****************************************************************************
- * 
+ *
  *				CloseGBP: close the port
  *
  *****************************************************************************/
@@ -592,7 +592,7 @@ RESPONSECODE CloseGBP(DWORD lun)
 
 
 /*****************************************************************************
- * 
+ *
  *				ExplainGBP: print a textual error explanation
  *
  *****************************************************************************/
@@ -710,7 +710,7 @@ int ExplainGBP(const unsigned char buffer[], const int rv)
 				DEBUG_COMM("  S: a command has been sent with an incorrect number of parameters");
 				break;
 			case 0x1C:
-				DEBUG_COMM("  S: overlap on writting flash memory");
+				DEBUG_COMM("  S: overlap on writing flash memory");
 				break;
 			case 0x1D:
 				DEBUG_COMM("  S: the TCK check byte is incorrect in a micropocessor card ATR");
@@ -778,7 +778,7 @@ int ExplainGBP(const unsigned char buffer[], const int rv)
 } /* ExplainGBP */
 
 /*****************************************************************************
- * 
+ *
  *				ExplainGBP: print a textual error explanation
  *
  *****************************************************************************/
