@@ -11,7 +11,7 @@
 #define STATUS_PCB_SYNC_RESP 0x1003
 #define STATUS_NAD_UNKNOWN 0x1004
 
-RESPONSECODE OpenGBP(DWORD lun, LPTSTR dev_name);
+RESPONSECODE OpenGBP(DWORD lun, LPSTR dev_name);
 RESPONSECODE WriteGBP(DWORD lun, DWORD length, unsigned char *Buffer);
 RESPONSECODE ReadGBP(DWORD lun, unsigned long *length, unsigned char *Buffer);
 RESPONSECODE CloseGBP(DWORD lun);
