@@ -1,6 +1,6 @@
 /*
  * libusb_wrap.c
- * $Id: libusb_wrap.c,v 1.24 2012/04/08 19:09:46 rousseau Exp $
+ * $Id: libusb_wrap.c,v 1.25 2017/12/14 17:49:14 rousseau Exp $
  * USB access routines using the libusb library
  *
  * Created by Ludovic Rousseau on Sep 27 2002
@@ -261,7 +261,7 @@ status_t WriteUSB(DWORD lun, DWORD length, unsigned char *buffer)
 			 * unpluged-repluged */
 			if (errno == ETIMEDOUT)
 			{
-				DEBUG_CRITICAL3("Reseting the reader: %s/%s",
+				DEBUG_CRITICAL3("Resetting the reader: %s/%s",
 					usbDevice[reader].dev->bus->dirname,
 					usbDevice[reader].dev->filename);
 				usb_reset(usbDevice[reader].handle);
