@@ -3,7 +3,7 @@
 /       Author: David Corcoran
 /      Purpose: Abstracts usb API to serial like calls
 /      License: See file COPYING
-/         $Id: usbserial_mosx.c,v 1.16 2009-02-17 19:57:05 rousseau Exp $
+/         $Id: usbserial_mosx.c,v 1.18 2012/04/08 19:09:46 rousseau Exp $
 ************************************************************/
 
 
@@ -46,11 +46,11 @@ static int                      iInitialized = FALSE;
 
 typedef struct _intFace {
   IOUSBInterfaceInterface182  **iface;
-  IOUSBDeviceInterface182     	**dev;
-  UInt32 			usbAddr;
+  IOUSBDeviceInterface182	**dev;
+  UInt32			usbAddr;
   UInt8				inPipeRef;
   UInt8				outPipeRef;
-  
+
 } intrFace, *pIntrFace;
 
 static pIntrFace intFace[USBMAX_READERS];
@@ -64,32 +64,32 @@ void FreeintFace()
     for (i=0; i < USBMAX_READERS; i++) {
         free(intFace[i]);
 
-    }    
+    }
 }
 
-gcore_t OpenUSB( DWORD lun, DWORD Channel)
+status_t OpenUSB( DWORD lun, DWORD Channel)
 {
-    CFMutableDictionaryRef 		USBMatch = 0;
-    io_iterator_t 			iter = 0;
-    io_service_t 			USBDevice = 0;
-    io_service_t        		USBIface = 0;
+    CFMutableDictionaryRef		USBMatch = 0;
+    io_iterator_t			iter = 0;
+    io_service_t			USBDevice = 0;
+    io_service_t			USBIface = 0;
     kern_return_t			kr;
-    io_iterator_t       		iterB = 0;
+    io_iterator_t			iterB = 0;
     SInt32				score;
-    IOUSBFindInterfaceRequest 		findInterface;
-    IOCFPlugInInterface 		**iodev=NULL;
+    IOUSBFindInterfaceRequest		findInterface;
+    IOCFPlugInInterface			**iodev=NULL;
     IOCFPlugInInterface			**iodevB=NULL;
-    HRESULT 				res;
+    HRESULT				res;
     DWORD				rdrLun;
-    SInt32	 			hpManu_id, hpProd_id;
-    UInt32   				usbAddr,usbAddrtest;
+    SInt32				hpManu_id, hpProd_id;
+    UInt32				usbAddr,usbAddrtest;
     short				iFound;
     int					i;
     IOUSBConfigurationDescriptorPtr     confDesc;
     UInt8				intfNumEndpoints;
     UInt8				direction, number, transferType, interval;
     UInt16				maxPacketSize;
-    mach_port_t 		masterPort;
+    mach_port_t			masterPort;
 
     CFBundleRef myBundle;
     CFStringRef propertyString;
@@ -101,8 +101,8 @@ gcore_t OpenUSB( DWORD lun, DWORD Channel)
     hpManu_id = 0;
     hpProd_id = 0;
 
-    
-    
+
+
     // Look for a bundle using its identifier
     if (!(myBundle = CFBundleGetBundleWithIdentifier(CFSTR("free.pcsc.GemPC430") )))
     {
@@ -116,7 +116,7 @@ gcore_t OpenUSB( DWORD lun, DWORD Channel)
         return STATUS_UNSUCCESSFUL;
     }
 
-    
+
     propertyString = CFDictionaryGetValue(bundleInfoDict,
                                           CFSTR("ifdVendorID"));
     if (propertyString == NULL)
@@ -124,12 +124,12 @@ gcore_t OpenUSB( DWORD lun, DWORD Channel)
         DEBUG_CRITICAL("Bundle InfoDic error: ifdVendorID not found");
         return STATUS_UNSUCCESSFUL;
     }
-    
+
     cStringValue = CFStringGetCStringPtr(propertyString,
                                          CFStringGetSystemEncoding());
     hpManu_id = strtoul(cStringValue, 0, 16);
 
-    
+
     propertyString = CFDictionaryGetValue(bundleInfoDict,
                                           CFSTR("ifdProductID"));
     if (propertyString == 0)
@@ -154,15 +154,15 @@ gcore_t OpenUSB( DWORD lun, DWORD Channel)
                                          CFStringGetSystemEncoding());
        ReadTimeOut = strtoul(cStringValue, 0, 10);
     }
-    
+
     DEBUG_CRITICAL2("Driver configured to detect Vendor ID = %04X", hpManu_id);
     DEBUG_CRITICAL2("Driver configured to detect Product ID = %04X", hpProd_id);
-    
+
     iFound = FALSE;
     rdrLun = lun >> 16;
-    
+
     if ( iInitialized == FALSE ) {
-                
+
         for (i=0; i < USBMAX_READERS; i++) {
             intFace[i] = (pIntrFace)malloc(sizeof(intrFace));
             if (!intFace[i])
@@ -177,7 +177,7 @@ gcore_t OpenUSB( DWORD lun, DWORD Channel)
             (intFace[i])->inPipeRef = 0;
             (intFace[i])->outPipeRef = 0;
         }
-    
+
         iInitialized = TRUE;
 
     }
@@ -191,7 +191,7 @@ gcore_t OpenUSB( DWORD lun, DWORD Channel)
         return STATUS_UNSUCCESSFUL;
     }
 
-    
+
 
     USBMatch = IOServiceMatching(kIOUSBDeviceClassName);
     if (!USBMatch)
@@ -201,21 +201,21 @@ gcore_t OpenUSB( DWORD lun, DWORD Channel)
         FreeintFace();
         return STATUS_UNSUCCESSFUL;
     }
-    
+
 
 
     CFDictionarySetValue(USBMatch,
                          CFSTR(kUSBVendorName),
-                         CFNumberCreate(kCFAllocatorDefault, 
+                         CFNumberCreate(kCFAllocatorDefault,
                                         kCFNumberSInt32Type,
                                         &hpManu_id));
     CFDictionarySetValue(USBMatch,
-                         CFSTR(kUSBProductName), 
+                         CFSTR(kUSBProductName),
                          CFNumberCreate(kCFAllocatorDefault,
-                                        kCFNumberSInt32Type, 
+                                        kCFNumberSInt32Type,
                                         &hpProd_id));
 
-    
+
 
 
     /* create an iterator over all matching IOService nubs */
@@ -224,7 +224,7 @@ gcore_t OpenUSB( DWORD lun, DWORD Channel)
     {
         DEBUG_CRITICAL2("Can't create a USB Service iterator (0x%08X)", kr);
 //?
-        CFRelease(USBMatch); 
+        CFRelease(USBMatch);
         mach_port_deallocate(mach_task_self(), masterPort);
         return STATUS_UNSUCCESSFUL;
     }
@@ -234,17 +234,17 @@ gcore_t OpenUSB( DWORD lun, DWORD Channel)
 
     while ( (USBDevice = IOIteratorNext(iter)) )
     {
-        
-        kr = IOCreatePlugInInterfaceForService(USBDevice, kIOUSBDeviceUserClientTypeID,         						kIOCFPlugInInterfaceID, &iodev, &score);
+
+        kr = IOCreatePlugInInterfaceForService(USBDevice, kIOUSBDeviceUserClientTypeID, kIOCFPlugInInterfaceID, &iodev, &score);
         IOObjectRelease(USBDevice);	/* done with the device object now */
         if (kr || !iodev)
         {
             DEBUG_CRITICAL2("unable to create a plugin (0x%08X)", kr);
             continue;
         }
-            
+
         /* i have the device plugin. I need the device interface */
-        res = (*iodev)->QueryInterface(iodev, CFUUIDGetUUIDBytes(kIOUSBDeviceInterfaceID), 						(LPVOID)&(intFace[rdrLun])->dev);
+        res = (*iodev)->QueryInterface(iodev, CFUUIDGetUUIDBytes(kIOUSBDeviceInterfaceID), (LPVOID)&(intFace[rdrLun])->dev);
         //(*iodev)->Release(iodev);
         if (res || !(intFace[rdrLun])->dev)
         {
@@ -254,7 +254,7 @@ gcore_t OpenUSB( DWORD lun, DWORD Channel)
 
         kr = (*(intFace[rdrLun])->dev)->GetLocationID(((intFace[rdrLun])->dev), &usbAddr);
 
-        
+
         for (i=0; i < USBMAX_READERS; i++)
         {
             if ( usbAddr == (intFace[i])->usbAddr )
@@ -274,7 +274,7 @@ gcore_t OpenUSB( DWORD lun, DWORD Channel)
     }
 
 
-    if ((intFace[rdrLun])->dev == NULL) 
+    if ((intFace[rdrLun])->dev == NULL)
     {
         /* Device not found */
         CFRelease(USBMatch);
@@ -282,10 +282,10 @@ gcore_t OpenUSB( DWORD lun, DWORD Channel)
     }
 
     kr = (*(intFace[rdrLun])->dev)->GetLocationID(((intFace[rdrLun])->dev), &usbAddrtest);
-    
+
 
     kr = (*(intFace[rdrLun])->dev)->USBDeviceOpen(((intFace[rdrLun])->dev));
-    if (kr == kIOReturnExclusiveAccess) 
+    if (kr == kIOReturnExclusiveAccess)
     {
         sleep(1);
         // Try to re-open in case Classic is using the device
@@ -307,7 +307,7 @@ gcore_t OpenUSB( DWORD lun, DWORD Channel)
     }
 
 
-    kr = (*(intFace[rdrLun])->dev)->GetConfigurationDescriptorPtr(((intFace[rdrLun])->dev), 0, &confDesc); 
+    kr = (*(intFace[rdrLun])->dev)->GetConfigurationDescriptorPtr(((intFace[rdrLun])->dev), 0, &confDesc);
     if (kr)
     {
         DEBUG_CRITICAL("ERR: unable to get the configuration");
@@ -328,8 +328,8 @@ gcore_t OpenUSB( DWORD lun, DWORD Channel)
         return STATUS_UNSUCCESSFUL;
     }
 
-    
-        
+
+
     /* Time to find the first interface */
     findInterface.bInterfaceClass    = kIOUSBFindInterfaceDontCare;
     findInterface.bInterfaceSubClass = kIOUSBFindInterfaceDontCare;
@@ -339,7 +339,7 @@ gcore_t OpenUSB( DWORD lun, DWORD Channel)
     kr = (*(intFace[rdrLun])->dev)->CreateInterfaceIterator(
                                                             ((intFace[rdrLun])->dev), &findInterface, &iterB );
     USBIface = IOIteratorNext(iterB);
-    
+
     if ( USBIface == 0 ) {
         DEBUG_CRITICAL("No interface found");
         return STATUS_UNSUCCESSFUL;
@@ -349,12 +349,12 @@ gcore_t OpenUSB( DWORD lun, DWORD Channel)
 
 
     /* Create the plugin for the interface service */
-    kr  = IOCreatePlugInInterfaceForService(USBIface, kIOUSBInterfaceUserClientTypeID, 			  				    kIOCFPlugInInterfaceID, &iodevB, &score);
-    res = (*iodev)->QueryInterface(iodevB, CFUUIDGetUUIDBytes(kIOUSBInterfaceInterfaceID),  
+    kr  = IOCreatePlugInInterfaceForService(USBIface, kIOUSBInterfaceUserClientTypeID, kIOCFPlugInInterfaceID, &iodevB, &score);
+    res = (*iodev)->QueryInterface(iodevB, CFUUIDGetUUIDBytes(kIOUSBInterfaceInterfaceID),
                                   (LPVOID)&(intFace[rdrLun])->iface);
 
     (intFace[rdrLun])->usbAddr = usbAddr;
-     
+
 
     /* Open the interface to open all the pipes */
     kr = (*(intFace[rdrLun])->iface)->USBInterfaceOpen((intFace[rdrLun])->iface);
@@ -379,7 +379,7 @@ gcore_t OpenUSB( DWORD lun, DWORD Channel)
     // pipes are one based, since zero is the default control pipe
     for (i=1; i <= intfNumEndpoints; i++)
     {
-        kr = (*(intFace[rdrLun])->iface)->GetPipeProperties((intFace[rdrLun])->iface, i, &direction, 						&number, &transferType, &maxPacketSize, &interval);
+        kr = (*(intFace[rdrLun])->iface)->GetPipeProperties((intFace[rdrLun])->iface, i, &direction, &number, &transferType, &maxPacketSize, &interval);
         if (kr != kIOReturnSuccess )
         {
             DEBUG_CRITICAL2("unable to get pipe properties: 0x%08X", kr);
@@ -400,7 +400,7 @@ gcore_t OpenUSB( DWORD lun, DWORD Channel)
 
     }
 
-    
+
     if ( !((intFace[rdrLun])->outPipeRef) )
     {
         DEBUG_CRITICAL2("unable to get outPipe: 0x%08X", kr);
@@ -416,21 +416,21 @@ gcore_t OpenUSB( DWORD lun, DWORD Channel)
     }
 
     DEBUG_CRITICAL2("New reader found at USB address: %08X", (intFace[rdrLun])->usbAddr);
-    
-    return STATUS_SUCCESS;  
+
+    return STATUS_SUCCESS;
 }
 
-gcore_t WriteUSB( DWORD lun, DWORD length, unsigned char *buffer )
+status_t WriteUSB( DWORD lun, DWORD length, unsigned char *buffer )
 {
     IOReturn		iorv;
     DWORD		rdrLun;
-     
+
     rdrLun = lun >> 16;
-         
+
     DEBUG_XXD("Attempt to write: ", buffer, length);
-        
+
     /* Make sure the pipe is OK */
-    iorv = (*(intFace[rdrLun])->iface)->GetPipeStatus( (intFace[rdrLun])->iface, 
+    iorv = (*(intFace[rdrLun])->iface)->GetPipeStatus( (intFace[rdrLun])->iface,
                                                             (intFace[rdrLun])->outPipeRef );
     if ( iorv != kIOReturnSuccess ) {
         return STATUS_UNSUCCESSFUL;
@@ -440,25 +440,25 @@ gcore_t WriteUSB( DWORD lun, DWORD length, unsigned char *buffer )
     iorv = (*(intFace[rdrLun])->iface)->WritePipe((intFace[rdrLun])->iface,
                                                   (intFace[rdrLun])->outPipeRef,
                                                   buffer, length);
-    
+
     if ( iorv != kIOReturnSuccess ) {
         return STATUS_UNSUCCESSFUL;
     }
-            
+
     return STATUS_SUCCESS;
 }
 
-gcore_t ReadUSB( DWORD lun, DWORD *length, unsigned char *buffer )
+status_t ReadUSB( DWORD lun, DWORD *length, unsigned char *buffer )
 {
     IOReturn		iorv;
     UInt32		recvLen;
     UInt32              noDataTO, completeTO;
     DWORD		rdrLun;
-    
+
     rdrLun = lun >> 16;
-    
+
     DEBUG_COMM2("Attempt to read %ld bytes", *length);
-    
+
     /* Make sure the pipe is OK */
     iorv = (*(intFace[rdrLun])->iface)->GetPipeStatus( (intFace[rdrLun])->iface,
                                                        (intFace[rdrLun])->inPipeRef
@@ -479,25 +479,25 @@ gcore_t ReadUSB( DWORD lun, DWORD *length, unsigned char *buffer )
         (*(intFace[rdrLun])->dev)->ResetDevice(((intFace[rdrLun])->dev));
         return STATUS_UNSUCCESSFUL;
     }
-    
+
     DEBUG_XXD("received: ", buffer, recvLen);
-    
+
     *length = recvLen;
     return STATUS_SUCCESS;
 }
 
-gcore_t CloseUSB( DWORD lun )
+status_t CloseUSB( DWORD lun )
 {
     IOReturn iorv;
     DWORD rdrLun;
-    
+
     rdrLun = lun >> 16;
 
     // Reset struct
     (intFace[rdrLun])->usbAddr = 0;
     (intFace[rdrLun])->outPipeRef = 0;
     (intFace[rdrLun])->inPipeRef = 0;
-    
+
 
     /* Close the interface and rid the iterator */
     iorv = (*(intFace[rdrLun])->iface)->USBInterfaceClose( (intFace[rdrLun])->iface );
@@ -515,7 +515,7 @@ gcore_t CloseUSB( DWORD lun )
 
     (*(intFace[rdrLun])->dev)->Release((intFace[rdrLun])->dev);
 
-    
+
 
     if ( iorv != kIOReturnSuccess ) {
         return STATUS_UNSUCCESSFUL;
