@@ -1,6 +1,6 @@
 /*
  *  GCCmds.c
- *  $Id: GCCmds.c,v 1.42 2010-01-03 15:48:40 rousseau Exp $
+ *  $Id: GCCmds.c,v 1.43 2012/04/08 18:38:19 rousseau Exp $
  *  ifd-GemPC
  *
  *  Created by Jean-Luc Giraud on Sat Oct 20 2001.
@@ -322,7 +322,6 @@ ifd_t GCCmdGetOSVersion(const DWORD lun, PDWORD length, UCHAR buffer[])
 
 	UCHAR cmd[] = { IFD_CMD_MEM_RD, IFD_TYP_VERSION, IFD_ADD_VERSION_HIGH,
 		IFD_ADD_VERSION_LOW, IFD_LEN_VERSION };
-	ifd_t rv;
 	gcore_t gc_rv;
 
 	DEBUG_INFO("");
@@ -337,7 +336,7 @@ ifd_t GCCmdGetOSVersion(const DWORD lun, PDWORD length, UCHAR buffer[])
 	memset(buffer, 0, *length);
 	/* decrease length by 1 to be sure their is room for the final \0 */
 	(*length)--;
-	rv = GCMakeCommand(lun, sizeof(cmd), cmd, length, buffer, &gc_rv);
+	GCMakeCommand(lun, sizeof(cmd), cmd, length, buffer, &gc_rv);
 	GCGemCoreError(gc_rv, __FILE__, __LINE__, __FUNCTION__);
 
 	if (gc_rv != GCORE_OK)
