@@ -1,5 +1,5 @@
 /*
- *  $Id: GCUtils.c,v 1.21 2004-07-03 21:42:48 rousseau Exp $
+ *  $Id: GCUtils.c,v 1.23 2012/04/08 19:09:47 rousseau Exp $
  *  GCUtils.c
  *  ifd-GemPC
  *
@@ -42,8 +42,7 @@ const UCHAR pcLongDataADPU[] = { 0xFF, 0xFF, 0xFF, 0xFF, 0xFF };
  * returns TRUE in case of error */
 int iLunCheck(DWORD Lun)
 {
-	if ((LunToReaderIndex(Lun) >= PCSCLITE_MAX_READERS) ||
-		LunToReaderIndex(Lun) < 0)
+	if (LunToReaderIndex(Lun) >= PCSCLITE_MAX_READERS)
 		return TRUE;
 
 	return FALSE;
@@ -231,7 +230,7 @@ ifd_t gemcore_ISO_EXCHANGE_processing(DWORD Lun, PUCHAR TxBuffer,
 		/* Length to send is now smaller */
 		TxLength = GC_ISO_EXC_CMD_MAX_APDU_LENGTH;
 	}
-	
+
 	/* Build the commmand */
 	pccmd_buffer[GC_OFFSET_CMD] = IFD_CMD_ICC_APDU;
 	memcpy(pccmd_buffer + GC_OFFSET_APDU, TxBuffer, TxLength);
@@ -273,10 +272,10 @@ ifd_t gemcore_ISO_EXCHANGE_processing(DWORD Lun, PUCHAR TxBuffer,
 			/* No space left in buffer, return directly */
 			goto clean_up_and_return;
 		}
-		
+
 		memcpy(RxBuffer, pcbuffer + GC_OFFSET_RESP_DATA,
 			GC_ISO_EXC_RESP_MAX_APDU_LENGTH);
-		
+
 		/* set nlength to remaining space avaliable in RxBuffer */
 		nlength = *RxLength - GC_ISO_EXC_RESP_MAX_APDU_LENGTH;
 
@@ -325,7 +324,7 @@ ifd_t gemcore_status_processing(DWORD nlength, PDWORD RxLength,
 			*RxLength = (*RxLength < nlength) ? (*RxLength) : nlength;
 			memcpy(RxBuffer, pcbuffer + GC_OFFSET_RESP_DATA, *RxLength);
 			break;
-			
+
 		case GCORE_CARD_MUTE:
 			return IFD_RESPONSE_TIMEOUT;
 
@@ -398,7 +397,7 @@ clean_up_and_return:
 } /* gemcore_long_data_INPUT_processing */
 
 /*
- * nbuf_size should hold the max length available in pcbuffer 
+ * nbuf_size should hold the max length available in pcbuffer
  */
 ifd_t gemcore_long_data_OUTPUT_processing(DWORD Lun, UCHAR cCMD,
 	DWORD nbuf_size, PDWORD RxLength, PUCHAR pcbuffer)
