@@ -13,7 +13,7 @@
 /            See http://www.linuxnet.com for more information.
 / License:   See file COPYING.BSD
 /
-/ $Id: ifdhandler.c,v 1.29 2009-04-12 09:24:07 rousseau Exp $
+/ $Id: ifdhandler.c,v 1.31 2012/04/08 19:09:47 rousseau Exp $
 /
 ******************************************************************/
 
@@ -48,7 +48,7 @@ static GCoreDesc pgSlots[PCSCLITE_MAX_READERS];
 
 RESPONSECODE IFDHCreateChannelByName(DWORD Lun, LPSTR lpcDevice)
 {
-	DEBUG_INFO3("lun: %X, device: %s", Lun, lpcDevice);
+	DEBUG_INFO3("lun: %lX, device: %s", Lun, lpcDevice);
 
 	if (iLunCheck(Lun))
 		return IFD_COMMUNICATION_ERROR;
@@ -110,7 +110,7 @@ RESPONSECODE IFDHCreateChannel(DWORD Lun, DWORD Channel)
 	 */
 	RESPONSECODE return_value = IFD_SUCCESS;
 
-	DEBUG_INFO3("lun: %X, channel: %d", Lun, Channel);
+	DEBUG_INFO3("lun: %lX, channel: %ld", Lun, Channel);
 
 	if (iLunCheck(Lun))
 		return IFD_COMMUNICATION_ERROR;
@@ -146,7 +146,7 @@ RESPONSECODE IFDHCloseChannel(DWORD Lun)
 	 * IFD_SUCCESS IFD_COMMUNICATION_ERROR
 	 */
 
-	DEBUG_INFO2("lun: %X", Lun);
+	DEBUG_INFO2("lun: %lX", Lun);
 
 	if (iLunCheck(Lun))
 		return IFD_COMMUNICATION_ERROR;
@@ -181,7 +181,7 @@ RESPONSECODE IFDHGetCapabilities(DWORD Lun, DWORD Tag,
 	 * IFD_SUCCESS IFD_ERROR_TAG
 	 */
 
-	DEBUG_INFO3("lun: %X, tag: %X", Lun, Tag);
+	DEBUG_INFO3("lun: %lX, tag: %lX", Lun, Tag);
 
 	if (iLunCheck(Lun))
 		return IFD_COMMUNICATION_ERROR;
@@ -237,7 +237,7 @@ RESPONSECODE IFDHSetCapabilities(DWORD Lun, DWORD Tag,
 
 	/* By default, say it worked */
 
-	DEBUG_PERIODIC3("lun: %X, tag: %X", Lun, Tag);
+	DEBUG_PERIODIC3("lun: %lX, tag: %lX", Lun, Tag);
 	(void)Length;
 	(void)Value;
 
@@ -266,7 +266,7 @@ RESPONSECODE IFDHSetProtocolParameters(DWORD Lun, DWORD Protocol,
 	 * IFD_PROTOCOL_NOT_SUPPORTED
 	 */
 
-	DEBUG_INFO2("lun: %X", Lun);
+	DEBUG_INFO2("lun: %lX", Lun);
 	(void)Protocol;
 	(void)Flags;
 	(void)PTS1;
@@ -323,7 +323,7 @@ RESPONSECODE IFDHPowerICC(DWORD Lun, DWORD Action,
 	RESPONSECODE return_value = IFD_SUCCESS;
 	UCHAR pcbuffer[RESP_BUF_SIZE];
 
-	DEBUG_INFO2("lun: %X", Lun);
+	DEBUG_INFO2("lun: %lX", Lun);
 
 	/* By default, assume it won't work :) */
 	*AtrLength = 0;
@@ -418,7 +418,7 @@ RESPONSECODE IFDHTransmitToICC(DWORD Lun, SCARD_IO_HEADER SendPci,
 	RESPONSECODE return_value = IFD_SUCCESS;	/* Assume it will work */
 	DWORD protocol;
 
-	DEBUG_INFO2("lun: %X", Lun);
+	DEBUG_INFO2("lun: %lX", Lun);
 	(void)RecvPci;
 
 	if (iLunCheck(Lun))
@@ -441,7 +441,7 @@ RESPONSECODE IFDHTransmitToICC(DWORD Lun, SCARD_IO_HEADER SendPci,
 				return_value = IFD_COMMUNICATION_ERROR;
 				goto clean_up_and_return;
 			}
-			
+
 			/* Check if this is an incoming or outgoing command
 			 * Size should be command + one byte of length for
 			 * an outgoing TPDU (CLA, INS, P1, P2, P3) */
@@ -554,7 +554,7 @@ RESPONSECODE IFDHControl(DWORD Lun, DWORD ControlCode, PUCHAR TxBuffer,
 	 * Notes: RxLength should be zero on error.
 	 */
 
-	DEBUG_INFO2("lun: %X", Lun);
+	DEBUG_INFO2("lun: %lX", Lun);
 	(void)ControlCode;
 	(void)TxBuffer;
 	(void)TxLength;
@@ -582,7 +582,7 @@ RESPONSECODE IFDHICCPresence(DWORD Lun)
 	RESPONSECODE return_value = IFD_COMMUNICATION_ERROR;
 	DWORD length;
 
-	DEBUG_PERIODIC2("lun: %X", Lun);
+	DEBUG_PERIODIC2("lun: %lX", Lun);
 
 	if (iLunCheck(Lun))
 		return IFD_COMMUNICATION_ERROR;
@@ -603,7 +603,7 @@ RESPONSECODE IFDHICCPresence(DWORD Lun)
 			DEBUG_PERIODIC("Card present and powered");
 			/* Powered, so the ressource manager did not miss a quick
 			 * removal/re-insertion */
-			
+
 			return_value = IFD_ICC_PRESENT;
 			goto clean_up_and_return;
 		}
@@ -648,7 +648,7 @@ RESPONSECODE IFDHICCPresence(DWORD Lun)
 			*pgSlots[LunToReaderIndex(Lun)].pcATRBuffer = '\0';
 			/* reset power flags */
 			pgSlots[LunToReaderIndex(Lun)].bPowerFlags = POWERFLAGS_RAZ;
-			
+
 			return_value = IFD_ICC_PRESENT;
 			goto clean_up_and_return;
 		}
